Tkinter steroids (tk_steroids)

Contains some useful GUI elements (tkinter widgets) that keep reoccuring
in the code elsewhere, such as a multiple selection box or matplotlib
integration using matplotlib's tkinter backend.
